
# kstandard

kstandard is a personal Python package I, [karsh](https://karsh.me), have created to hold the common
code I use across my projects. It includes things like type aliases and helpful functions.


### Features
- Type Aliases: A selection of custom type aliases for better code clarity.
- Debugging Function: My debug_print() function for easy debugging.
- Useful Utilities: Various general-purpose functions to make life easier.


### Installation
This package can be installed like any other pip package with:
```sh
$ pip install kstandard
```

